import React, { ComponentPropsWithoutRef } from 'react';
import { Orientation } from '../../@types';
export declare enum RadioGroupVariantEnum {
    'list' = 0,
    'stacked' = 1
}
export interface IRadioGroupOption {
    description: string | React.ReactNode;
    disabled?: boolean;
    label: string | React.ReactNode;
    value: string | number;
}
export interface IRadioGroupProps extends ComponentPropsWithoutRef<'input'> {
    /**
     * Defines disabled state
     */
    disabled?: boolean;
    /**
     * Defines label for SR-Only
     */
    label?: string;
    /**
     * Defines onChange event handler function
     */
    onChange: (value: any) => void;
    /**
     * Defines className for options wrapper element.
     */
    optionClassName?: string;
    /**
     * Defines className for options content element.
     */
    optionContentClassName?: string;
    /**
     * Defines options list
     */
    options: IRadioGroupOption[];
    /**
     * Defines Orientation. i.e "horizontal" or "vertical"
     */
    orientation?: keyof typeof Orientation;
    /**
     * Defines whether to show Redio element or not.
     */
    showRadio?: boolean;
    /**
     * Defines selected item value
     */
    value: any;
    /**
     * Defines variant. i.e. "list" or "stacked"
     */
    variant?: keyof typeof RadioGroupVariantEnum;
    /**
     * Defines whether is dark mode ot not(default)
     */
    isDarkMode?: boolean;
}
export interface IRadioGroupOptionProps extends ComponentPropsWithoutRef<'option'> {
    index: number;
    option: IRadioGroupOption;
    showRadio?: boolean;
    isDarkMode?: boolean;
    contentClassName: string;
}
declare const RadioGroup: React.ForwardRefExoticComponent<IRadioGroupProps & React.RefAttributes<HTMLInputElement>>;
export declare const RadioGroupOption: ({ className, index, option, showRadio, isDarkMode, contentClassName, }: IRadioGroupOptionProps) => JSX.Element;
export default RadioGroup;
//# sourceMappingURL=RadioGroup.d.ts.map